@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 from plone.app.caching.interfaces import IPloneCacheSettings
 from plone.app.caching.testing import PLONE_APP_CACHING_FUNCTIONAL_TESTING
+from plone.app.caching.tests.test_utils import normalize_etag
 from plone.app.caching.tests.test_utils import stable_now
+from plone.app.caching.tests.test_utils import test_image
 from plone.app.testing import applyProfile
 from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
@@ -24,32 +26,10 @@ import datetime
 import dateutil.parser
 import dateutil.tz
 import os
-import pkg_resources
 import six
 import unittest
 
 
-TEST_FILE = pkg_resources.resource_filename(
-    'plone.app.caching.tests', 'test.gif')
-
-
-def test_image():
-    from plone.namedfile.file import NamedBlobImage
-    filename = pkg_resources.resource_filename(
-        'plone.app.caching.tests', 'test.gif')
-    filename = os.path.join(os.path.dirname(__file__), u'test.gif')
-    return NamedBlobImage(
-        data=open(filename, 'rb').read(),
-        filename=filename,
-    )
-
-
-def _normalize_etag(s):
-    s = s.split('|')
-    s.pop()  # remove time-based component
-    return '|'.join(s)
-
-
 class TestProfileWithCaching(unittest.TestCase):
     """This test aims to exercise the caching operations expected from the
     `with-caching-proxy` profile.
@@ -147,8 +127,8 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
-        ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
+        self.assertEqual('"|test_user_1_|%d|en|%s|0|0' % (catalog.getCounter(
+        ), skins_tool.default_skin), normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
@@ -162,8 +142,8 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
-        ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
+        self.assertEqual('"|test_user_1_|%d|en|%s|0|1' % (catalog.getCounter(
+        ), skins_tool.default_skin), normalize_etag(browser.headers['ETag']))
 
         # Request the authenticated page
         now = stable_now()
@@ -181,8 +161,8 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"|test_user_1_|%d|en|%s' % (catalog.getCounter(
-        ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
+        self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
+        ), skins_tool.default_skin), normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
@@ -227,8 +207,8 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
-        ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
+        self.assertEqual('"||%d|en|%s|0|0' % (catalog.getCounter(
+        ), skins_tool.default_skin), normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
@@ -244,8 +224,8 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"||%d|en|%s' % (catalog.getCounter(
-        ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
+        self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
+        ), skins_tool.default_skin), normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
@@ -264,8 +244,8 @@ class TestProfileWithCaching(unittest.TestCase):
         self.assertIn(testText, browser.contents)
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"||%d|en|%s' % (catalog.getCounter(
-        ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
+        self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
+        ), skins_tool.default_skin), normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
