@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from Acquisition import Explicit
+from datetime import date
 from datetime import datetime
 from plone.app.caching.interfaces import IPloneCacheSettings
 from plone.app.caching.utils import getObjectDefaultView
@@ -15,11 +16,14 @@ from zope.component import provideAdapter
 from zope.component import provideUtility
 from zope.interface import implementer
 
+import pkg_resources
 import pytz
 import unittest
 
 
 TEST_TIMEZONE = 'Europe/Vienna'
+TEST_IMAGE = pkg_resources.resource_filename(
+    u'plone.app.caching.tests', u'test.gif')
 
 
 def stable_now():
@@ -31,6 +35,27 @@ def stable_now():
     return now
 
 
+def normalize_etag(value):
+    split_value = value.split('|')
+    # The last component is expected to be the resourceRegistries ETag,
+    # which is a time-based component, making it hard to test.
+    last = split_value.pop()
+    if str(date.today().year) in last:
+        # yes, this is time based, remove it
+        return '|'.join(split_value)
+    # return original
+    return value
+
+
+def test_image():
+    from plone.namedfile.file import NamedBlobImage
+    with open(TEST_IMAGE, 'rb') as myfile:
+        return NamedBlobImage(
+            data=myfile.read(),
+            filename=TEST_IMAGE,
+        )
+
+
 @implementer(IBrowserDefault, IDynamicType)
 class DummyContent(Explicit):
 
